@@ -130,7 +130,7 @@ class DiscreteEnv(gym.Env):
             Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Xaa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Ya=np.random.binomial(1, 0.5, self.size)))
-    self.model = LogisticRegression().fit(self.dfa[["Xsa", "Xaa"]], np.ravel(self.dfa[["Ya"]].astype(int)))
+    self.modela = LogisticRegression().fit(self.dfa[["Xsa", "Xaa"]], np.ravel(self.dfa[["Ya"]].astype(int)))
 
     #extract theta parameters from the fitted logistic
     self.thetasa = np.array([self.modela.coef_[0,0] , self.modela.coef_[0,1], self.modela.intercept_[0]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
